<p align='center'>
  <br/>
  <img src="https://github.com/richteague/gofish/blob/master/docs/_static/logo.png" width="596" height="527"><br/>
  <br>
  <b>Fishing for molecular line detections in protoplanetary disks.</b>
  <br>
  For more information, read the documentation.
  <br>
  <br>
  <a href='https://fishing.readthedocs.io/en/latest/?badge=latest'>
      <img src='https://readthedocs.org/projects/fishing/badge/?version=latest' alt='Documentation Status' />
  </a>
</p>
